# Setting Up a Custom SMTP Server for Email Notifications
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/setting-up-custom-smtp-server-for-email-notifications#overview)
  * [Authentication](https://help.sap.com/docs/leanix/ea/setting-up-custom-smtp-server-for-email-notifications#authentication)
  * [Configuring a Custom SMTP Server](https://help.sap.com/docs/leanix/ea/setting-up-custom-smtp-server-for-email-notifications#configuring-a-custom-smtp-server)


Set up a custom Simple Mail Transfer Protocol (SMTP) server to ensure enhanced security standards for email notification delivery.
